@@ -139,7 +139,7 @@ main(int argc, char **argv)
 	gtk_init(&argc, &argv);
 
 	dlg = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title(GTK_WINDOW(dlg), _("XFce tips and tricks"));
+	gtk_window_set_title(GTK_WINDOW(dlg), _("Xfce tips and tricks"));
 	gtk_window_stick(GTK_WINDOW(dlg));
 	gtk_window_set_default_size(GTK_WINDOW(dlg), 600, 400);
 	gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
@@ -148,9 +148,9 @@ main(int argc, char **argv)
 	gtk_widget_show(vbox1);
 	gtk_container_add(GTK_CONTAINER(dlg), vbox1);
 
-	logo = inline_icon_at_size(xfce_logo_data, 48, 48);
+	logo = xfce_inline_icon_at_size(xfce_logo_data, 48, 48);
 	text = g_strdup_printf(_("Tips and tricks"));
-	header = create_header(logo, text);
+	header = xfce_create_header(logo, text);
 	gtk_widget_show(header);
 	gtk_box_pack_start(GTK_BOX(vbox1), header, FALSE, FALSE, 0);
 	g_object_unref(logo);
